# mkdocs-blogging-plugin

A mkdocs plugin that generates a blog page listing selected pages, sorted by time.

- Automatically generates a blog index page
- Can be grouped by tags
- Support deep customization without dirty work

![preview](https://s2.loli.net/2021/12/03/GqhwCYTsimlkXK1.png)

## Prerequisites

- Only `material` theme is adapted by far
- `navigation.instant` feature cannot be enabled if blog paging is on

Pull requests are welcome to break these constraints.

## Installation

```shell
# macOS or Linux
pip3 install mkdocs-blogging-plugin

# Windows
pip install mkdocs-blogging-plugin
```

## Usage

A complete guide is available at https://liang2kl.github.io/mkdocs-blogging-plugin.

You might need to follow the [migration guide](https://liang2kl.github.io/mkdocs-blogging-plugin/migration)
to upgrade to a new version.

## Credits

Inspired by [mkdocs-git-revision-date-localized-plugin](https://github.com/timvink/mkdocs-git-revision-date-localized-plugin) and [mkdocs-material-blog](https://github.com/vuquangtrong/mkdocs-material-blog).
